// %flair:license{
// This file is part of the Flair framework distributed under the
// CECILL-C License, Version 1.0.
// %flair:license}
//  created:    2020/11/20
//  filename:   TwoWheelRobot.h
//
//  author:     Guillaume Sanahuja
//              Copyright Heudiasyc UMR UTC/CNRS 7253
//
//  version:    $Id: $
//
//  purpose:    classe definissant un TwoWheelRobot
//
/*********************************************************************/

#ifndef TWOWHEELROBOT_H
#define TWOWHEELROBOT_H

#include <Model.h>

namespace flair {
namespace core {
class Mutex;
}
namespace gui {
class DoubleSpinBox;
class SpinBox;
}
namespace actuator {
class SimuUgvControls;
}
}

#ifdef GL
namespace irr {
namespace scene {
class IMesh;
}
}
#endif

namespace flair {
namespace simulator {
class Blade;

class TwoWheelRobot : public Model {
public:
  TwoWheelRobot(std::string name, uint32_t modelId);
  ~TwoWheelRobot();
#ifdef GL
  virtual void Draw(void);
  virtual void ExtraDraw(void){}; 
#endif

private:
  void CalcModel(void);
#ifdef GL
  void AnimateModel(void);
  size_t dbtSize(void) const;
  void WritedbtBuf(char *dbtbuf);
  void ReaddbtBuf(char *dbtbuf);
  irr::scene::IMesh *colored_body;
#endif
  gui::SpinBox *bodyColorR,*bodyColorG,*bodyColorB;
  gui::DoubleSpinBox *size,*m;
  actuator::SimuUgvControls *controls;

 
};
} // end namespace simulator
} // end namespace flair
#endif // TWOWHEELROBOT_H
